==> drools-wb-guided-dtree-editor-api-7.6.0.Final-sources.jar: org/drools/workbench/screens/guided/dtree/service/GuidedDecisionTreeEditorService.java <==
/*
 * Copyright 2014 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.workbench.screens.guided.dtree.service;

import org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree;
import org.drools.workbench.screens.guided.dtree.model.GuidedDecisionTreeEditorContent;
import org.guvnor.common.services.shared.file.SupportsUpdate;
import org.guvnor.common.services.shared.validation.ValidationService;
import org.jboss.errai.bus.server.annotations.Remote;
import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
import org.kie.workbench.common.services.shared.source.ViewSourceService;
import org.uberfire.backend.vfs.Path;
import org.uberfire.ext.editor.commons.service.support.SupportsCopy;
import org.uberfire.ext.editor.commons.service.support.SupportsCreate;
import org.uberfire.ext.editor.commons.service.support.SupportsDelete;
import org.uberfire.ext.editor.commons.service.support.SupportsRead;
import org.uberfire.ext.editor.commons.service.support.SupportsRename;

@Remote
public interface GuidedDecisionTreeEditorService
        extends
        ViewSourceService<GuidedDecisionTree>,
        ValidationService<GuidedDecisionTree>,
        SupportsCreate<GuidedDecisionTree>,
        SupportsRead<GuidedDecisionTree>,
        SupportsUpdate<GuidedDecisionTree>,
        SupportsDelete,
        SupportsCopy,
        SupportsRename {

    GuidedDecisionTreeEditorContent loadContent( final Path path );

    PackageDataModelOracleBaselinePayload loadDataModel( final Path path );

}

==> drools-wb-guided-dtree-editor-api-7.43.0.Final-sources.jar: org/drools/workbench/screens/guided/dtree/service/GuidedDecisionTreeEditorService.java <==
/*
 * Copyright 2014 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.workbench.screens.guided.dtree.service;

import org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree;
import org.drools.workbench.screens.guided.dtree.model.GuidedDecisionTreeEditorContent;
import org.guvnor.common.services.shared.metadata.model.Metadata;
import org.guvnor.common.services.shared.validation.ValidationService;
import org.jboss.errai.bus.server.annotations.Remote;
import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
import org.kie.workbench.common.services.shared.source.ViewSourceService;
import org.uberfire.backend.vfs.Path;
import org.uberfire.ext.editor.commons.service.support.SupportsCopy;
import org.uberfire.ext.editor.commons.service.support.SupportsCreate;
import org.uberfire.ext.editor.commons.service.support.SupportsDelete;
import org.uberfire.ext.editor.commons.service.support.SupportsRead;
import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;

@Remote
public interface GuidedDecisionTreeEditorService
        extends
        ViewSourceService<GuidedDecisionTree>,
        ValidationService<GuidedDecisionTree>,
        SupportsCreate<GuidedDecisionTree>,
        SupportsRead<GuidedDecisionTree>,
        SupportsSaveAndRename<GuidedDecisionTree, Metadata>,
        SupportsDelete,
        SupportsCopy {

    GuidedDecisionTreeEditorContent loadContent(final Path path);

    PackageDataModelOracleBaselinePayload loadDataModel(final Path path);
}
